# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkdataworks_public.endpoint import endpoint_data

class CreateFileRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'dataworks-public', '2020-05-18', 'CreateFile')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_FileType(self):
		return self.get_body_params().get('FileType')

	def set_FileType(self,FileType):
		self.add_body_params('FileType', FileType)

	def get_DependentNodeIdList(self):
		return self.get_body_params().get('DependentNodeIdList')

	def set_DependentNodeIdList(self,DependentNodeIdList):
		self.add_body_params('DependentNodeIdList', DependentNodeIdList)

	def get_Content(self):
		return self.get_body_params().get('Content')

	def set_Content(self,Content):
		self.add_body_params('Content', Content)

	def get_ProjectIdentifier(self):
		return self.get_body_params().get('ProjectIdentifier')

	def set_ProjectIdentifier(self,ProjectIdentifier):
		self.add_body_params('ProjectIdentifier', ProjectIdentifier)

	def get_ResourceGroupId(self):
		return self.get_body_params().get('ResourceGroupId')

	def set_ResourceGroupId(self,ResourceGroupId):
		self.add_body_params('ResourceGroupId', ResourceGroupId)

	def get_ProjectId(self):
		return self.get_body_params().get('ProjectId')

	def set_ProjectId(self,ProjectId):
		self.add_body_params('ProjectId', ProjectId)

	def get_StartEffectDate(self):
		return self.get_body_params().get('StartEffectDate')

	def set_StartEffectDate(self,StartEffectDate):
		self.add_body_params('StartEffectDate', StartEffectDate)

	def get_CycleType(self):
		return self.get_body_params().get('CycleType')

	def set_CycleType(self,CycleType):
		self.add_body_params('CycleType', CycleType)

	def get_Owner(self):
		return self.get_body_params().get('Owner')

	def set_Owner(self,Owner):
		self.add_body_params('Owner', Owner)

	def get_AutoRerunIntervalMillis(self):
		return self.get_body_params().get('AutoRerunIntervalMillis')

	def set_AutoRerunIntervalMillis(self,AutoRerunIntervalMillis):
		self.add_body_params('AutoRerunIntervalMillis', AutoRerunIntervalMillis)

	def get_InputList(self):
		return self.get_body_params().get('InputList')

	def set_InputList(self,InputList):
		self.add_body_params('InputList', InputList)

	def get_RerunMode(self):
		return self.get_body_params().get('RerunMode')

	def set_RerunMode(self,RerunMode):
		self.add_body_params('RerunMode', RerunMode)

	def get_ConnectionName(self):
		return self.get_body_params().get('ConnectionName')

	def set_ConnectionName(self,ConnectionName):
		self.add_body_params('ConnectionName', ConnectionName)

	def get_ParaValue(self):
		return self.get_body_params().get('ParaValue')

	def set_ParaValue(self,ParaValue):
		self.add_body_params('ParaValue', ParaValue)

	def get_ResourceGroupIdentifier(self):
		return self.get_body_params().get('ResourceGroupIdentifier')

	def set_ResourceGroupIdentifier(self,ResourceGroupIdentifier):
		self.add_body_params('ResourceGroupIdentifier', ResourceGroupIdentifier)

	def get_AutoRerunTimes(self):
		return self.get_body_params().get('AutoRerunTimes')

	def set_AutoRerunTimes(self,AutoRerunTimes):
		self.add_body_params('AutoRerunTimes', AutoRerunTimes)

	def get_CronExpress(self):
		return self.get_body_params().get('CronExpress')

	def set_CronExpress(self,CronExpress):
		self.add_body_params('CronExpress', CronExpress)

	def get_EndEffectDate(self):
		return self.get_body_params().get('EndEffectDate')

	def set_EndEffectDate(self,EndEffectDate):
		self.add_body_params('EndEffectDate', EndEffectDate)

	def get_FileName(self):
		return self.get_body_params().get('FileName')

	def set_FileName(self,FileName):
		self.add_body_params('FileName', FileName)

	def get_Stop(self):
		return self.get_body_params().get('Stop')

	def set_Stop(self,Stop):
		self.add_body_params('Stop', Stop)

	def get_DependentType(self):
		return self.get_body_params().get('DependentType')

	def set_DependentType(self,DependentType):
		self.add_body_params('DependentType', DependentType)

	def get_FileFolderPath(self):
		return self.get_body_params().get('FileFolderPath')

	def set_FileFolderPath(self,FileFolderPath):
		self.add_body_params('FileFolderPath', FileFolderPath)

	def get_FileDescription(self):
		return self.get_body_params().get('FileDescription')

	def set_FileDescription(self,FileDescription):
		self.add_body_params('FileDescription', FileDescription)


# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkdataworks_public.endpoint import endpoint_data

class CreateImportMigrationRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'dataworks-public', '2020-05-18', 'CreateImportMigration')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_Description(self):
		return self.get_body_params().get('Description')

	def set_Description(self,Description):
		self.add_body_params('Description', Description)

	def get_CommitRule(self):
		return self.get_body_params().get('CommitRule')

	def set_CommitRule(self,CommitRule):
		self.add_body_params('CommitRule', CommitRule)

	def get_WorkspaceMap(self):
		return self.get_body_params().get('WorkspaceMap')

	def set_WorkspaceMap(self,WorkspaceMap):
		self.add_body_params('WorkspaceMap', WorkspaceMap)

	def get_CalculateEngineMap(self):
		return self.get_body_params().get('CalculateEngineMap')

	def set_CalculateEngineMap(self,CalculateEngineMap):
		self.add_body_params('CalculateEngineMap', CalculateEngineMap)

	def get_Name(self):
		return self.get_body_params().get('Name')

	def set_Name(self,Name):
		self.add_body_params('Name', Name)

	def get_PackageType(self):
		return self.get_body_params().get('PackageType')

	def set_PackageType(self,PackageType):
		self.add_body_params('PackageType', PackageType)

	def get_ProjectId(self):
		return self.get_body_params().get('ProjectId')

	def set_ProjectId(self,ProjectId):
		self.add_body_params('ProjectId', ProjectId)

	def get_PackageOssDownloadLink(self):
		return self.get_body_params().get('PackageOssDownloadLink')

	def set_PackageOssDownloadLink(self,PackageOssDownloadLink):
		self.add_body_params('PackageOssDownloadLink', PackageOssDownloadLink)


# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkdataworks_public.endpoint import endpoint_data

class UpdateQualityRuleRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'dataworks-public', '2020-05-18', 'UpdateQualityRule')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_Trend(self):
		return self.get_body_params().get('Trend')

	def set_Trend(self,Trend):
		self.add_body_params('Trend', Trend)

	def get_BlockType(self):
		return self.get_body_params().get('BlockType')

	def set_BlockType(self,BlockType):
		self.add_body_params('BlockType', BlockType)

	def get_PropertyType(self):
		return self.get_body_params().get('PropertyType')

	def set_PropertyType(self,PropertyType):
		self.add_body_params('PropertyType', PropertyType)

	def get_EntityId(self):
		return self.get_body_params().get('EntityId')

	def set_EntityId(self,EntityId):
		self.add_body_params('EntityId', EntityId)

	def get_RuleName(self):
		return self.get_body_params().get('RuleName')

	def set_RuleName(self,RuleName):
		self.add_body_params('RuleName', RuleName)

	def get_Checker(self):
		return self.get_body_params().get('Checker')

	def set_Checker(self,Checker):
		self.add_body_params('Checker', Checker)

	def get_Operator(self):
		return self.get_body_params().get('Operator')

	def set_Operator(self,Operator):
		self.add_body_params('Operator', Operator)

	def get_Property(self):
		return self.get_body_params().get('Property')

	def set_Property(self,Property):
		self.add_body_params('Property', Property)

	def get_Id(self):
		return self.get_body_params().get('Id')

	def set_Id(self,Id):
		self.add_body_params('Id', Id)

	def get_WarningThreshold(self):
		return self.get_body_params().get('WarningThreshold')

	def set_WarningThreshold(self,WarningThreshold):
		self.add_body_params('WarningThreshold', WarningThreshold)

	def get_MethodName(self):
		return self.get_body_params().get('MethodName')

	def set_MethodName(self,MethodName):
		self.add_body_params('MethodName', MethodName)

	def get_ProjectName(self):
		return self.get_body_params().get('ProjectName')

	def set_ProjectName(self,ProjectName):
		self.add_body_params('ProjectName', ProjectName)

	def get_RuleType(self):
		return self.get_body_params().get('RuleType')

	def set_RuleType(self,RuleType):
		self.add_body_params('RuleType', RuleType)

	def get_TemplateId(self):
		return self.get_body_params().get('TemplateId')

	def set_TemplateId(self,TemplateId):
		self.add_body_params('TemplateId', TemplateId)

	def get_ExpectValue(self):
		return self.get_body_params().get('ExpectValue')

	def set_ExpectValue(self,ExpectValue):
		self.add_body_params('ExpectValue', ExpectValue)

	def get_WhereCondition(self):
		return self.get_body_params().get('WhereCondition')

	def set_WhereCondition(self,WhereCondition):
		self.add_body_params('WhereCondition', WhereCondition)

	def get_CriticalThreshold(self):
		return self.get_body_params().get('CriticalThreshold')

	def set_CriticalThreshold(self,CriticalThreshold):
		self.add_body_params('CriticalThreshold', CriticalThreshold)

	def get_Comment(self):
		return self.get_body_params().get('Comment')

	def set_Comment(self,Comment):
		self.add_body_params('Comment', Comment)

	def get_PredictType(self):
		return self.get_body_params().get('PredictType')

	def set_PredictType(self,PredictType):
		self.add_body_params('PredictType', PredictType)


# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkdataworks_public.endpoint import endpoint_data

class CreateDataServiceApiRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'dataworks-public', '2020-05-18', 'CreateDataServiceApi')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_ScriptDetails(self):
		return self.get_body_params().get('ScriptDetails')

	def set_ScriptDetails(self,ScriptDetails):
		self.add_body_params('ScriptDetails', ScriptDetails)

	def get_RequestMethod(self):
		return self.get_body_params().get('RequestMethod')

	def set_RequestMethod(self,RequestMethod):
		self.add_body_params('RequestMethod', RequestMethod)

	def get_GroupId(self):
		return self.get_body_params().get('GroupId')

	def set_GroupId(self,GroupId):
		self.add_body_params('GroupId', GroupId)

	def get_ApiPath(self):
		return self.get_body_params().get('ApiPath')

	def set_ApiPath(self,ApiPath):
		self.add_body_params('ApiPath', ApiPath)

	def get_WizardDetails(self):
		return self.get_body_params().get('WizardDetails')

	def set_WizardDetails(self,WizardDetails):
		self.add_body_params('WizardDetails', WizardDetails)

	def get_ApiMode(self):
		return self.get_body_params().get('ApiMode')

	def set_ApiMode(self,ApiMode):
		self.add_body_params('ApiMode', ApiMode)

	def get_VisibleRange(self):
		return self.get_body_params().get('VisibleRange')

	def set_VisibleRange(self,VisibleRange):
		self.add_body_params('VisibleRange', VisibleRange)

	def get_ApiDescription(self):
		return self.get_body_params().get('ApiDescription')

	def set_ApiDescription(self,ApiDescription):
		self.add_body_params('ApiDescription', ApiDescription)

	def get_Timeout(self):
		return self.get_body_params().get('Timeout')

	def set_Timeout(self,Timeout):
		self.add_body_params('Timeout', Timeout)

	def get_FolderId(self):
		return self.get_body_params().get('FolderId')

	def set_FolderId(self,FolderId):
		self.add_body_params('FolderId', FolderId)

	def get_RegistrationDetails(self):
		return self.get_body_params().get('RegistrationDetails')

	def set_RegistrationDetails(self,RegistrationDetails):
		self.add_body_params('RegistrationDetails', RegistrationDetails)

	def get_ApiName(self):
		return self.get_body_params().get('ApiName')

	def set_ApiName(self,ApiName):
		self.add_body_params('ApiName', ApiName)

	def get_TenantId(self):
		return self.get_body_params().get('TenantId')

	def set_TenantId(self,TenantId):
		self.add_body_params('TenantId', TenantId)

	def get_Protocols(self):
		return self.get_body_params().get('Protocols')

	def set_Protocols(self,Protocols):
		self.add_body_params('Protocols', Protocols)

	def get_ProjectId(self):
		return self.get_body_params().get('ProjectId')

	def set_ProjectId(self,ProjectId):
		self.add_body_params('ProjectId', ProjectId)

	def get_ResponseContentType(self):
		return self.get_body_params().get('ResponseContentType')

	def set_ResponseContentType(self,ResponseContentType):
		self.add_body_params('ResponseContentType', ResponseContentType)


# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkdataworks_public.endpoint import endpoint_data

class UpdateTableRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'dataworks-public', '2020-05-18', 'UpdateTable')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_Visibility(self):
		return self.get_query_params().get('Visibility')

	def set_Visibility(self,Visibility):
		self.add_query_param('Visibility',Visibility)

	def get_PhysicsLevelId(self):
		return self.get_query_params().get('PhysicsLevelId')

	def set_PhysicsLevelId(self,PhysicsLevelId):
		self.add_query_param('PhysicsLevelId',PhysicsLevelId)

	def get_Columnss(self):
		return self.get_body_params().get('Columns')

	def set_Columnss(self, Columnss):
		for depth1 in range(len(Columnss)):
			if Columnss[depth1].get('SeqNumber') is not None:
				self.add_body_params('Columns.' + str(depth1 + 1) + '.SeqNumber', Columnss[depth1].get('SeqNumber'))
			if Columnss[depth1].get('IsPartitionCol') is not None:
				self.add_body_params('Columns.' + str(depth1 + 1) + '.IsPartitionCol', Columnss[depth1].get('IsPartitionCol'))
			if Columnss[depth1].get('ColumnNameCn') is not None:
				self.add_body_params('Columns.' + str(depth1 + 1) + '.ColumnNameCn', Columnss[depth1].get('ColumnNameCn'))
			if Columnss[depth1].get('Length') is not None:
				self.add_body_params('Columns.' + str(depth1 + 1) + '.Length', Columnss[depth1].get('Length'))
			if Columnss[depth1].get('IsNullable') is not None:
				self.add_body_params('Columns.' + str(depth1 + 1) + '.IsNullable', Columnss[depth1].get('IsNullable'))
			if Columnss[depth1].get('Comment') is not None:
				self.add_body_params('Columns.' + str(depth1 + 1) + '.Comment', Columnss[depth1].get('Comment'))
			if Columnss[depth1].get('IsPrimaryKey') is not None:
				self.add_body_params('Columns.' + str(depth1 + 1) + '.IsPrimaryKey', Columnss[depth1].get('IsPrimaryKey'))
			if Columnss[depth1].get('ColumnName') is not None:
				self.add_body_params('Columns.' + str(depth1 + 1) + '.ColumnName', Columnss[depth1].get('ColumnName'))
			if Columnss[depth1].get('ColumnType') is not None:
				self.add_body_params('Columns.' + str(depth1 + 1) + '.ColumnType', Columnss[depth1].get('ColumnType'))

	def get_OwnerId(self):
		return self.get_query_params().get('OwnerId')

	def set_OwnerId(self,OwnerId):
		self.add_query_param('OwnerId',OwnerId)

	def get_LifeCycle(self):
		return self.get_query_params().get('LifeCycle')

	def set_LifeCycle(self,LifeCycle):
		self.add_query_param('LifeCycle',LifeCycle)

	def get_Themess(self):
		return self.get_body_params().get('Themes')

	def set_Themess(self, Themess):
		for depth1 in range(len(Themess)):
			if Themess[depth1].get('ThemeLevel') is not None:
				self.add_body_params('Themes.' + str(depth1 + 1) + '.ThemeLevel', Themess[depth1].get('ThemeLevel'))
			if Themess[depth1].get('ThemeId') is not None:
				self.add_body_params('Themes.' + str(depth1 + 1) + '.ThemeId', Themess[depth1].get('ThemeId'))

	def get_LogicalLevelId(self):
		return self.get_query_params().get('LogicalLevelId')

	def set_LogicalLevelId(self,LogicalLevelId):
		self.add_query_param('LogicalLevelId',LogicalLevelId)

	def get_Endpoint(self):
		return self.get_body_params().get('Endpoint')

	def set_Endpoint(self,Endpoint):
		self.add_body_params('Endpoint', Endpoint)

	def get_IsView(self):
		return self.get_query_params().get('IsView')

	def set_IsView(self,IsView):
		self.add_query_param('IsView',IsView)

	def get_ExternalTableType(self):
		return self.get_query_params().get('ExternalTableType')

	def set_ExternalTableType(self,ExternalTableType):
		self.add_query_param('ExternalTableType',ExternalTableType)

	def get_EnvType(self):
		return self.get_body_params().get('EnvType')

	def set_EnvType(self,EnvType):
		self.add_body_params('EnvType', EnvType)

	def get_HasPart(self):
		return self.get_query_params().get('HasPart')

	def set_HasPart(self,HasPart):
		self.add_query_param('HasPart',HasPart)

	def get_Location(self):
		return self.get_query_params().get('Location')

	def set_Location(self,Location):
		self.add_query_param('Location',Location)

	def get_TableName(self):
		return self.get_query_params().get('TableName')

	def set_TableName(self,TableName):
		self.add_query_param('TableName',TableName)

	def get_AppGuid(self):
		return self.get_query_params().get('AppGuid')

	def set_AppGuid(self,AppGuid):
		self.add_query_param('AppGuid',AppGuid)

	def get_ProjectId(self):
		return self.get_query_params().get('ProjectId')

	def set_ProjectId(self,ProjectId):
		self.add_query_param('ProjectId',ProjectId)

	def get_CategoryId(self):
		return self.get_query_params().get('CategoryId')

	def set_CategoryId(self,CategoryId):
		self.add_query_param('CategoryId',CategoryId)

	def get_CreateIfNotExists(self):
		return self.get_query_params().get('CreateIfNotExists')

	def set_CreateIfNotExists(self,CreateIfNotExists):
		self.add_query_param('CreateIfNotExists',CreateIfNotExists)